/* Copyright 2023-2025 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

int
main (void)
{
  int main = 1; /* Main body.  */

  asm ("foo_label: .global foo_label");
  int foo = 2; /* Foo body.  */
  asm ("foo_end: .global foo_end");

  asm ("bar_label: .global bar_label");
  int bar = 3; /* Bar body.  */
  asm ("bar_end: .global bar_end");

  return main + foo + bar;
}
